HeaderModel class
Properties
-
fixedColumnCount
↔ int
-
固定的header cell 个数
getter/setter pair
-
fixedColumnWidth
↔ double
-
固定的header总宽度
getter/setter pair
-
固定的header cell widgets
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
header每行cell宽度
getter/setter pair
-
header最大高度
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
固定的scrollable cell widgets
getter/setter pair
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
dispose()
→ void
-
Discards any resources used by the object.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
override
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset()
→ void
-
-
每次headerMaxHeight调整都会触发一次
-
toString()
→ String
-
A string representation of this object.
inherited