FreedomTableHeaderCell class

Constructors

FreedomTableHeaderCell({int? flex, double? fixedWidth, required Widget child, bool isFixedColumn = false})

Properties

child ↔ Widget
child widget
getter/setter pair
fixedWidth ↔ double?
set the header cell width in fixed width
getter/setter pair
flex ↔ int?
set the header cell width in flex mode
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFixedColumn ↔ bool
when the column is fixed when scroll horizontal, please ensure the column's child cell DON'T have colspan!!!
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthType ↔ CellWidthType
header cell width type is flex width or fixed width
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited