FreedomTableTheme class

Constructors

FreedomTableTheme({Color dividerColor = const Color(0xffe6e6e6), Color backgroundColor = const Color(0xfff2f2f2), Color hoverColor = const Color(0xfff6f6f6), Color hoverColorGetter()?, Color pagerBorderColor = const Color(0xffcccccc), Color pagerTextColor = const Color(0xff666666), Color pagerTextFocusedColor = const Color(0xffffffff), Color pagerTextDisabledColor = const Color(0xffcccccc), Color pagerFocusedBackgroundColor = const Color(0xff5078F0)})

Properties

backgroundColor → Color
body cell background color
final
dividerColor → Color
table divider color
final
hashCode → int
The hash code for this object.
no setterinherited
hoverColor → Color
body cell hover color
final
hoverColorGetter → Color Function()?
body cell hover color getter, this priority is higher than hoverColor
final
pagerBorderColor → Color
pager Border Color
final
pagerFocusedBackgroundColor → Color
pager Focused Background Color
final
pagerTextColor → Color
pager Text Color
final
pagerTextDisabledColor → Color
pager Text Disabled Color
final
pagerTextFocusedColor → Color
pager Text Focused Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited